==> flowable-engine-common-6.6.0-sources.jar: org/flowable/common/engine/impl/callback/CallbackData.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.common.engine.impl.callback;

/**
 * @author Joram Barrez
 */
public class CallbackData {
    
    protected String callbackId;
    protected String callbackType;
    protected String instanceId;
    protected String oldState;
    protected String newState;
    
    public CallbackData(String callbackId, String callbackType, String instanceId, String oldState, String newState) {
        this.callbackId = callbackId;
        this.callbackType = callbackType;
        this.instanceId = instanceId;
        this.oldState = oldState;
        this.newState = newState;
    }

    public String getCallbackId() {
        return callbackId;
    }

    public void setCallbackId(String callbackId) {
        this.callbackId = callbackId;
    }

    public String getCallbackType() {
        return callbackType;
    }

    public void setCallbackType(String callbackType) {
        this.callbackType = callbackType;
    }

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    public String getOldState() {
        return oldState;
    }

    public void setOldState(String oldState) {
        this.oldState = oldState;
    }

    public String getNewState() {
        return newState;
    }

    public void setNewState(String newState) {
        this.newState = newState;
    }
    
}

==> flowable-engine-common-6.8.0-sources.jar: org/flowable/common/engine/impl/callback/CallbackData.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.common.engine.impl.callback;

import java.util.Map;

/**
 * @author Joram Barrez
 */
public class CallbackData {
    
    protected String callbackId;
    protected String callbackType;
    protected String instanceId;
    protected String oldState;
    protected String newState;
    protected Map<String, Object> additionalData = null;

    public CallbackData(String callbackId, String callbackType, String instanceId, String oldState, String newState, Map<String, Object> additionalData) {
        this.callbackId = callbackId;
        this.callbackType = callbackType;
        this.instanceId = instanceId;
        this.oldState = oldState;
        this.newState = newState;
    }

    public CallbackData(String callbackId, String callbackType, String instanceId, String oldState, String newState) {
        this(callbackId, callbackType, instanceId, oldState, newState, null);
    }

    public String getCallbackId() {
        return callbackId;
    }

    public void setCallbackId(String callbackId) {
        this.callbackId = callbackId;
    }

    public String getCallbackType() {
        return callbackType;
    }

    public void setCallbackType(String callbackType) {
        this.callbackType = callbackType;
    }

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    public String getOldState() {
        return oldState;
    }

    public void setOldState(String oldState) {
        this.oldState = oldState;
    }

    public String getNewState() {
        return newState;
    }

    public void setNewState(String newState) {
        this.newState = newState;
    }

    public Map<String, Object> getAdditionalData() {
        return additionalData;
    }

    public void setAdditionalData(Map<String, Object> additionalData) {
        this.additionalData = additionalData;
    }

}
